package org.apache.bcel.util;

import java.lang.reflect.Method;
import java.lang.reflect.Modifier;
import org.apache.commons.lang3.StringUtils;

/* loaded from: org_apache_bcel_util.jar:org/apache/bcel/util/JavaWrapper.class */
public class JavaWrapper {
    private final java.lang.ClassLoader loader;

    private static java.lang.ClassLoader getClassLoader() {
        String s = System.getProperty("bcel.classloader");
        if (StringUtils.isEmpty(s)) {
            throw new IllegalStateException("The property 'bcel.classloader' must be defined");
        }
        try {
            return (java.lang.ClassLoader) Class.forName(s).newInstance();
        } catch (Exception e) {
            throw new IllegalStateException(e.toString(), e);
        }
    }

    public static void main(String[] argv) throws Exception {
        if (argv.length == 0) {
            System.out.println("Missing class name.");
            return;
        }
        String className = argv[0];
        String[] newArgv = new String[argv.length - 1];
        System.arraycopy(argv, 1, newArgv, 0, newArgv.length);
        new JavaWrapper().runMain(className, newArgv);
    }

    public JavaWrapper() {
        this(getClassLoader());
    }

    public JavaWrapper(java.lang.ClassLoader loader) {
        this.loader = loader;
    }

    public void runMain(String className, String[] argv) throws ClassNotFoundException {
        Class<?> cl = this.loader.loadClass(className);
        try {
            Method method = cl.getMethod("main", argv.getClass());
            int m = method.getModifiers();
            Class<?> r = method.getReturnType();
            if (!Modifier.isPublic(m) || !Modifier.isStatic(m) || Modifier.isAbstract(m) || r != Void.TYPE) {
                throw new NoSuchMethodException();
            }
            try {
                method.invoke(null, argv);
            } catch (Exception ex) {
                ex.printStackTrace();
            }
        } catch (NoSuchMethodException e) {
            System.out.println("In class " + className + ": public static void main(String[] argv) is not defined");
        }
    }
}
